{
  am_pm_abbreviated => [
    "comme",
    "lilli",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mua-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Cla",
    "Czi",
    "Cko",
    "Cka",
    "Cga",
    "Cze",
    "Cya",
  ],
  day_format_narrow => [
    "L",
    "Z",
    "O",
    "A",
    "G",
    "E",
    "Y",
  ],
  day_format_wide => [
    "Comlaa\N{U+0257}ii",
    "Comzyii\N{U+0257}ii",
    "Comkolle",
    "Comkald\N{U+01dd}\N{U+0253}lii",
    "Comgaisuu",
    "Comzye\N{U+0253}suu",
    "Com\N{U+2019}yakke",
  ],
  day_stand_alone_abbreviated => [
    "Cla",
    "Czi",
    "Cko",
    "Cka",
    "Cga",
    "Cze",
    "Cya",
  ],
  day_stand_alone_narrow => [
    "L",
    "Z",
    "O",
    "A",
    "G",
    "E",
    "Y",
  ],
  day_stand_alone_wide => [
    "Comlaa\N{U+0257}ii",
    "Comzyii\N{U+0257}ii",
    "Comkolle",
    "Comkald\N{U+01dd}\N{U+0253}lii",
    "Comgaisuu",
    "Comzye\N{U+0253}suu",
    "Com\N{U+2019}yakke",
  ],
  era_abbreviated => [
    "KK",
    "PK",
  ],
  era_narrow => [
    "KK",
    "PK",
  ],
  era_wide => [
    "K\N{U+01dd}Pel Kristu",
    "Pel Kristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Mundang",
  month_format_abbreviated => [
    "FLO",
    "CLA",
    "CKI",
    "FMF",
    "MAD",
    "MBI",
    "MLI",
    "MAM",
    "FDE",
    "FMU",
    "FGW",
    "FYU",
  ],
  month_format_narrow => [
    "O",
    "A",
    "I",
    "F",
    "D",
    "B",
    "L",
    "M",
    "E",
    "U",
    "W",
    "Y",
  ],
  month_format_wide => [
    "F\N{U+0129}i Loo",
    "Cokcwakla\N{U+014b}ne",
    "Cokcwaklii",
    "F\N{U+0129}i Marfoo",
    "Mad\N{U+01dd}\N{U+01dd}uut\N{U+01dd}bija\N{U+014b}",
    "Mam\N{U+01dd}\N{U+014b}gw\N{U+00e3}afahbii",
    "Mam\N{U+01dd}\N{U+014b}gw\N{U+00e3}alii",
    "Mad\N{U+01dd}mbii",
    "F\N{U+0129}i D\N{U+01dd}\N{U+0253}lii",
    "F\N{U+0129}i Munda\N{U+014b}",
    "F\N{U+0129}i Gwahlle",
    "F\N{U+0129}i Yuru",
  ],
  month_stand_alone_abbreviated => [
    "FLO",
    "CLA",
    "CKI",
    "FMF",
    "MAD",
    "MBI",
    "MLI",
    "MAM",
    "FDE",
    "FMU",
    "FGW",
    "FYU",
  ],
  month_stand_alone_narrow => [
    "O",
    "A",
    "I",
    "F",
    "D",
    "B",
    "L",
    "M",
    "E",
    "U",
    "W",
    "Y",
  ],
  month_stand_alone_wide => [
    "F\N{U+0129}i Loo",
    "Cokcwakla\N{U+014b}ne",
    "Cokcwaklii",
    "F\N{U+0129}i Marfoo",
    "Mad\N{U+01dd}\N{U+01dd}uut\N{U+01dd}bija\N{U+014b}",
    "Mam\N{U+01dd}\N{U+014b}gw\N{U+00e3}afahbii",
    "Mam\N{U+01dd}\N{U+014b}gw\N{U+00e3}alii",
    "Mad\N{U+01dd}mbii",
    "F\N{U+0129}i D\N{U+01dd}\N{U+0253}lii",
    "F\N{U+0129}i Munda\N{U+014b}",
    "F\N{U+0129}i Gwahlle",
    "F\N{U+0129}i Yuru",
  ],
  name => "Mundang Cameroon",
  native_language => "MUNDA\N{U+014a}",
  native_name => "MUNDA\N{U+014a} kameru\N{U+014b}",
  native_script => undef,
  native_territory => "kameru\N{U+014b}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Tai f\N{U+0129}i sai ma t\N{U+01dd}n kee zah",
    "Tai f\N{U+0129}i sai zah l\N{U+01dd}n gwa ma kee",
    "Tai f\N{U+0129}i sai zah l\N{U+01dd}n sai ma kee",
    "Tai f\N{U+0129}i sai ma coo kee zah \N{U+2018}na",
  ],
  quarter_stand_alone_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Tai f\N{U+0129}i sai ma t\N{U+01dd}n kee zah",
    "Tai f\N{U+0129}i sai zah l\N{U+01dd}n gwa ma kee",
    "Tai f\N{U+0129}i sai zah l\N{U+01dd}n sai ma kee",
    "Tai f\N{U+0129}i sai ma coo kee zah \N{U+2018}na",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
