{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "LLLL y G",
    GyMMMEd => "E d. M. y G",
    GyMMMMd => "d. M. y G",
    GyMMMd => "d. M. y G",
    GyMd => "d. M. y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmv => "H:mm v",
    M => "L.",
    MEd => "E d. M.",
    MMM => "LLL",
    MMMEd => "E d. M.",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-few" => "W. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' MMMM",
    "MMMMW-count-many" => "W. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' MMMM",
    "MMMMW-count-one" => "W. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' MMMM",
    "MMMMW-count-other" => "W. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. M.",
    Md => "d. M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d. M. y",
    yMMM => "M/y",
    yMMMEd => "E d. M. y",
    yMMMM => "LLLL y",
    yMMMMd => "d. MMMM y",
    yMMMd => "d. M. y",
    yMd => "d. M. y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "w. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' 'roka' Y",
    "yw-count-many" => "w. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' 'roka' Y",
    "yw-count-one" => "w. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' 'roka' Y",
    "yw-count-other" => "w. 't\N{U+00fd}\N{U+017e}de\N{U+0148}' 'roka' Y",
  },
  code => "sk-SK",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. M. y",
  date_format_short => "d. M. y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "po",
    "ut",
    "st",
    "\N{U+0161}t",
    "pi",
    "so",
    "ne",
  ],
  day_format_narrow => [
    "p",
    "u",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "pondelok",
    "utorok",
    "streda",
    "\N{U+0161}tvrtok",
    "piatok",
    "sobota",
    "nede\N{U+013e}a",
  ],
  day_stand_alone_abbreviated => [
    "po",
    "ut",
    "st",
    "\N{U+0161}t",
    "pi",
    "so",
    "ne",
  ],
  day_stand_alone_narrow => [
    "p",
    "u",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "pondelok",
    "utorok",
    "streda",
    "\N{U+0161}tvrtok",
    "piatok",
    "sobota",
    "nede\N{U+013e}a",
  ],
  era_abbreviated => [
    "pred Kr.",
    "po Kr.",
  ],
  era_narrow => [
    "pred Kr.",
    "po Kr.",
  ],
  era_wide => [
    "pred Kristom",
    "po Kristovi",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a\240%e.\240%B\240%Y,\240%H:%M:%S\240%Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a\240%e.\240%B\240%Y,\240%H:%M:%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Slovak",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "m\N{U+00e1}j",
    "j\N{U+00fa}n",
    "j\N{U+00fa}l",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "janu\N{U+00e1}ra",
    "febru\N{U+00e1}ra",
    "marca",
    "apr\N{U+00ed}la",
    "m\N{U+00e1}ja",
    "j\N{U+00fa}na",
    "j\N{U+00fa}la",
    "augusta",
    "septembra",
    "okt\N{U+00f3}bra",
    "novembra",
    "decembra",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "m\N{U+00e1}j",
    "j\N{U+00fa}n",
    "j\N{U+00fa}l",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "janu\N{U+00e1}r",
    "febru\N{U+00e1}r",
    "marec",
    "apr\N{U+00ed}l",
    "m\N{U+00e1}j",
    "j\N{U+00fa}n",
    "j\N{U+00fa}l",
    "august",
    "september",
    "okt\N{U+00f3}ber",
    "november",
    "december",
  ],
  name => "Slovak Slovakia",
  native_language => "sloven\N{U+010d}ina",
  native_name => "sloven\N{U+010d}ina Slovensko",
  native_script => undef,
  native_territory => "Slovensko",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+0161}tvr\N{U+0165}rok",
    "2. \N{U+0161}tvr\N{U+0165}rok",
    "3. \N{U+0161}tvr\N{U+0165}rok",
    "4. \N{U+0161}tvr\N{U+0165}rok",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+0161}tvr\N{U+0165}rok",
    "2. \N{U+0161}tvr\N{U+0165}rok",
    "3. \N{U+0161}tvr\N{U+0165}rok",
    "4. \N{U+0161}tvr\N{U+0165}rok",
  ],
  script => undef,
  territory => "Slovakia",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 40,
}
