{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'ika'-W 'linggo' 'ng' MMMM",
    "MMMMW-count-other" => "'linggo' W 'ng' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'ika'-w 'linggo' 'ng' Y",
    "yw-count-other" => "'linggo' w 'ng' Y",
  },
  code => "fil",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} 'nang' {0}",
  datetime_format_long => "{1} 'nang' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Lun",
    "Mar",
    "Miy",
    "Huw",
    "Biy",
    "Sab",
    "Lin",
  ],
  day_format_narrow => [
    "Lun",
    "Mar",
    "Miy",
    "Huw",
    "Biy",
    "Sab",
    "Lin",
  ],
  day_format_wide => [
    "Lunes",
    "Martes",
    "Miyerkules",
    "Huwebes",
    "Biyernes",
    "Sabado",
    "Linggo",
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mar",
    "Miy",
    "Huw",
    "Biy",
    "Sab",
    "Lin",
  ],
  day_stand_alone_narrow => [
    "Lun",
    "Mar",
    "Miy",
    "Huw",
    "Biy",
    "Sab",
    "Lin",
  ],
  day_stand_alone_wide => [
    "Lunes",
    "Martes",
    "Miyerkules",
    "Huwebes",
    "Biyernes",
    "Sabado",
    "Linggo",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Before Christ",
    "Anno Domini",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Filipino",
  month_format_abbreviated => [
    "Ene",
    "Peb",
    "Mar",
    "Abr",
    "May",
    "Hun",
    "Hul",
    "Ago",
    "Set",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_format_narrow => [
    "Ene",
    "Peb",
    "Mar",
    "Abr",
    "May",
    "Hun",
    "Hul",
    "Ago",
    "Set",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_format_wide => [
    "Enero",
    "Pebrero",
    "Marso",
    "Abril",
    "Mayo",
    "Hunyo",
    "Hulyo",
    "Agosto",
    "Setyembre",
    "Oktubre",
    "Nobyembre",
    "Disyembre",
  ],
  month_stand_alone_abbreviated => [
    "Ene",
    "Peb",
    "Mar",
    "Abr",
    "May",
    "Hun",
    "Hul",
    "Ago",
    "Set",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "E",
    "P",
    "M",
    "A",
    "M",
    "Hun",
    "Hul",
    "Ago",
    "Set",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_stand_alone_wide => [
    "Enero",
    "Pebrero",
    "Marso",
    "Abril",
    "Mayo",
    "Hunyo",
    "Hulyo",
    "Agosto",
    "Setyembre",
    "Oktubre",
    "Nobyembre",
    "Disyembre",
  ],
  name => "Filipino",
  native_language => "Filipino",
  native_name => "Filipino",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ika-1 quarter",
    "ika-2 quarter",
    "ika-3 quarter",
    "ika-4 na quarter",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ika-1 quarter",
    "ika-2 quarter",
    "ika-3 quarter",
    "ika-4 na quarter",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 40,
}
