{
  am_pm_abbreviated => [
    "krn",
    "koosk",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kln-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Kot",
    "Koo",
    "Kos",
    "Koa",
    "Kom",
    "Kol",
    "Kts",
  ],
  day_format_narrow => [
    "T",
    "O",
    "S",
    "A",
    "M",
    "L",
    "T",
  ],
  day_format_wide => [
    "Kotaai",
    "Koaeng\N{U+2019}",
    "Kosomok",
    "Koang\N{U+2019}wan",
    "Komuut",
    "Kolo",
    "Kotisap",
  ],
  day_stand_alone_abbreviated => [
    "Kot",
    "Koo",
    "Kos",
    "Koa",
    "Kom",
    "Kol",
    "Kts",
  ],
  day_stand_alone_narrow => [
    "T",
    "O",
    "S",
    "A",
    "M",
    "L",
    "T",
  ],
  day_stand_alone_wide => [
    "Kotaai",
    "Koaeng\N{U+2019}",
    "Kosomok",
    "Koang\N{U+2019}wan",
    "Komuut",
    "Kolo",
    "Kotisap",
  ],
  era_abbreviated => [
    "AM",
    "KO",
  ],
  era_narrow => [
    "AM",
    "KO",
  ],
  era_wide => [
    "Amait kesich Jesu",
    "Kokakesich Jesu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kalenjin",
  month_format_abbreviated => [
    "Mul",
    "Ngat",
    "Taa",
    "Iwo",
    "Mam",
    "Paa",
    "Nge",
    "Roo",
    "Bur",
    "Epe",
    "Kpt",
    "Kpa",
  ],
  month_format_narrow => [
    "M",
    "N",
    "T",
    "I",
    "M",
    "P",
    "N",
    "R",
    "B",
    "E",
    "K",
    "K",
  ],
  month_format_wide => [
    "Mulgul",
    "Ng\N{U+2019}atyaato",
    "Kiptaamo",
    "Iwootkuut",
    "Mamuut",
    "Paagi",
    "Ng\N{U+2019}eiyeet",
    "Rooptui",
    "Bureet",
    "Epeeso",
    "Kipsuunde ne taai",
    "Kipsuunde nebo aeng\N{U+2019}",
  ],
  month_stand_alone_abbreviated => [
    "Mul",
    "Ngat",
    "Taa",
    "Iwo",
    "Mam",
    "Paa",
    "Nge",
    "Roo",
    "Bur",
    "Epe",
    "Kpt",
    "Kpa",
  ],
  month_stand_alone_narrow => [
    "M",
    "N",
    "T",
    "I",
    "M",
    "P",
    "N",
    "R",
    "B",
    "E",
    "K",
    "K",
  ],
  month_stand_alone_wide => [
    "Mulgul",
    "Ng\N{U+2019}atyaato",
    "Kiptaamo",
    "Iwootkuut",
    "Mamuut",
    "Paagi",
    "Ng\N{U+2019}eiyeet",
    "Rooptui",
    "Bureet",
    "Epeeso",
    "Kipsuunde ne taai",
    "Kipsuunde nebo aeng\N{U+2019}",
  ],
  name => "Kalenjin Kenya",
  native_language => "Kalenjin",
  native_name => "Kalenjin Emetab Kenya",
  native_script => undef,
  native_territory => "Emetab Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Robo netai",
    "Robo nebo aeng\N{U+2019}",
    "Robo nebo somok",
    "Robo nebo ang\N{U+2019}wan",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Robo netai",
    "Robo nebo aeng\N{U+2019}",
    "Robo nebo somok",
    "Robo nebo ang\N{U+2019}wan",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
